<?php
class PressbackPrincipal {

	function index(){
		global $pressbackup;

		$preferences= get_option('pressbackup_preferences');

		if(!$preferences['pressbackup']['configured'])
		{
			$redirect=array('menu_type'=>'settings', 'controller'=>'settings', 'function'=>'config_init');
		}
		else
		{
			$redirect=array('controller'=>'principal', 'function'=>'dashboard');
		}

		$pressbackup->redirect($redirect);
	}

//------------------------------
//	Pages
//------------------------------

	/*
		@from = [this_site|all_sites], dahboard for this site of for all sites?
	*/

	function dashboard($from = null, $reload=false, $page = null)
	{
		global $pressbackup;
		$pressbackup->import('misc.php');
		$pressbackup->View->layout('principal');
		$preferences= get_option('pressbackup_preferences');

		//check what dashboard we are seeing last time
		if(!$pressbackup->Session->check('dashboard_from')){
			if(!$from){$from='this_site';}
			$pressbackup->Session->write('dashboard_from', $from);
		}
		elseif($from && $pressbackup->Session->read('dashboard_from') != $from)
		{
			$pressbackup->Session->write('dashboard_from', $from);
			$page=1;
		}
		$from = $pressbackup->Session->read('dashboard_from');

		//retrive backups from Amazon S3
		if($preferences['pressbackup']['s3']['credential'])
		{
			$pressbackup->import('S3.php');
			$credentials=explode('|AllYouNeedIsLove|', base64_decode($preferences['pressbackup']['s3']['credential']));
			$s3 = new S3($credentials[0], $credentials[1]);
			$bucket_files = $s3->getBucket($preferences['pressbackup']['s3']['bucket_name']);
			$bucket_files= @pressbackup_msort('S3', $bucket_files);
			$bucket_files= filter_files ($from, $bucket_files);
		}

		//retrive backups from Pro
		elseif($preferences['pressbackup']['pressbackuppro']['credential'])
		{
			$pressbackup->import('Pro.php');
			$credentials=explode('|AllYouNeedIsLove|', base64_decode($preferences['pressbackup']['pressbackuppro']['credential']));
			$pbp = new pressbackup($credentials[0], $credentials[1]);
			$bucket_files = $pbp->getFilesList();
			$bucket_files= pressbackup_msort('pressbackup', $bucket_files);
			$bucket_files= filter_files ($from, $bucket_files);
		}

		//inicializacion del paginador
		if (isset($bucket_files) && $bucket_files) {
			$pressbackup->import('paginator.php');
			$pag = new PressbackPaginator();
			$pagination_size = 5;

			$page_saved = $pressbackup->Session->read('dash.page');
			if(!$page && !$page_saved){
				$page = 1;
			}
			elseif(!$page && $page_saved){
				$page = $page_saved;
			}
			if(!array_slice($bucket_files, (($page -1 )*$pagination_size), $pagination_size, true) && $page > 1){
				$page--;
			}
			$pressbackup->Session->write('dash.page', $page);

			$paginator['page'] = $page ;
			$paginator['total']  = count($bucket_files);
			$paginator['pages'] = ceil ($paginator['total'] /$pagination_size);
			$paginator['ini']  = (($page -1 )*$pagination_size);
			$paginator['fin']  = (($page*$pagination_size) -1);
			$paginator['func_path']  = array('controller'=>'principal', 'function'=>'dashboard', $from, null);
			$paginator['pagination'] = $pagination_size;
			$pressbackup->View->set('paginator', $pag->get_html($paginator));
			$pressbackup->View->set('bucket_files', array_slice($bucket_files, $paginator['ini'], $pagination_size, true));
		}

		//set the type of credential to see what option show in this page
		$credentials = false;
		$credential_type = null;
		if($preferences['pressbackup']['s3']['credential']) {
			$credentials= true; $credential_type='Amazon S3';
		}
		elseif($preferences['pressbackup']['pressbackuppro']['credential']) {
			$credentials= true; $credential_type='Pressbackup Pro';
		}

		//set messages
		if($pressbackup->Session->check('general_msg')){
			$pressbackup->Msg->general($pressbackup->Session->read('general_msg'));
			$pressbackup->Session->delete('general_msg');
		}

		//set errors
		if($pressbackup->Session->check('error_msg')){
			$pressbackup->Msg->error($pressbackup->Session->read('error_msg'));
			$pressbackup->Session->delete('error_msg');
		}

		//set errors de permisos
		if($pressbackup->Session->check('error_msg_perm')){
			$pressbackup->View->set('perm_problem', $pressbackup->Session->read('error_msg_perm'));
			$pressbackup->Session->delete('error_msg_perm');
		}

		//check for activated schedule
		if (!$ns=wp_next_scheduled('pressback_schedule_job', array('save_schedule'))){
			$pressbackup->import('backup_functions.php');
			$pb = new pressbackup_backup();
			$pb->add_schedule();
			$ns=wp_next_scheduled('pressback_schedule_job', array('save_schedule'));
		}

		$pressbackup->View->set('from', $from);
		$pressbackup->View->set('settings', $preferences);
		$pressbackup->View->set('credentials', $credentials);
		$pressbackup->View->set('credential_type', $credential_type);
		$pressbackup->View->set('ns', $ns);
		$pressbackup->View->set('reload', $reload);
	}

	function backup_upload_page ()
	{
		//tools & info
		global $pressbackup;
		$pressbackup->import('misc.php');
		$pressbackup->View->layout('principal');
		$preferences= get_option('pressbackup_preferences');

		//set error from previus upload
		if($pressbackup->Session->check('error_msg')){
			$pressbackup->Msg->error($pressbackup->Session->read('error_msg'));
			$pressbackup->Session->delete('error_msg');
		}

		//check for folder permissions
		$permissions = array();
		$disable = false;
		$msg = false;

		$dir = WP_CONTENT_DIR . DS;
		if( substr(sprintf('%o', @fileperms( $dir . 'themes')), -3) < '777'){ $permissions[] ='themes'; }
		if( file_exists($dir . 'uploads') && substr(sprintf('%o', @fileperms( $dir . 'uploads')), -3) < '777'){ $permissions[] ='uploads'; }
		if( substr(sprintf('%o', @fileperms( $dir . 'plugins')), -3) < '777'){ $permissions[] ='plugins'; }

		if($permissions) {
			$msg = "Warning: permissions denied to write on <b>".join('</b>, <b>', $permissions)."</b> folder/s, change the permissions if you want to be able to restore a backup";
			$disable = true;
		}

		$pressbackup->View->set('upload_size', pressbackup_get_size_in('m', pressbackup_upload_max_filesize()));
		$pressbackup->View->set('settings', $preferences);
		$pressbackup->View->set('disblable_msg', $msg);
		$pressbackup->View->set('disable_ulpoad', $disable);
	}


//------------------------------
//	functions
//------------------------------

	/*
		@then = [download|save|save_schedule], action after the backup creation
			save, store the backup on S3 or Pro server
			save_schedule is call from a cron and store the backup on S3 or Pro server
	*/

	function backup_create($then = 'download')
	{
		//some propertis for this script
		@set_time_limit(0);

		//tools
		global $pressbackup;
		$pressbackup->import('backup_functions.php');
		$preferences= get_option('pressbackup_preferences');

		//fix to missing rew schedule
		if ($then == 'save_schedule'){
			$pb = new pressbackup_backup();
			$pb->add_schedule();
		}

		//get the type of credential
		$credentials = false;
		$credential_type = null;
		if($preferences['pressbackup']['s3']['credential']) {
			$credentials= true; $credential_type='S3';
		}
		elseif($preferences['pressbackup']['pressbackuppro']['credential']) {
			$credentials= true; $credential_type='Pro';
		}

		//go back if trying to save on (S3, PRO) without credential for it
		if(!$credentials && in_array($then, array('save_schedule', 'save'))){
			$pressbackup->Session->write( 'error_msg',  "You have not access to {$credential_type} server");
			if($then == 'save_schedule'){
				//file_put_contents($pressbackup->Path->Dir['WPFTMP'].'/schedule.log',$pressbackup->Session->read('error_msg') );
				exit;
			}
			$pressbackup->redirect(array('controller'=>'principal', 'function'=>'dashboard'));
		}

		//create backup file
		$pb = new pressbackup_backup();
		if(!$zip_file_created = $pb->create()){
			if($then == 'save_schedule')
			{
				//file_put_contents($pressbackup->Path->Dir['WPFTMP'].'/schedule.log',$pressbackup->Session->read('error_msg') );
				exit;
			}
			$pressbackup->redirect(array('controller'=>'principal', 'function'=>'dashboard'));
		}

		//see what to do with backup created
		switch($then){
			case 'download':
				//clean output buffer (to can use headers)
				ob_end_clean();
				//download it
				$pressbackup->import('download.php');
				$pressbackup->View->set('file', $zip_file_created);
			break;

			case 'save':
				$pressbackup->Session->write( 'general_msg',  "backup created!, we are sending it. you will see it in a moment");
				$pressbackup->redirect(array('controller'=>'principal', 'function'=>'dashboard', null, true), false);
				sleep(1);
				$pb->save_on($credential_type, $zip_file_created);
				exit();
			break;

			case 'save_schedule':
				//close conection and keep working
				$href = $pressbackup->Path->router(array('controller'=>'principal', 'function'=>'dashboard'));
				$pressbackup->kick_user($href);
				$pb->save_on($credential_type, $zip_file_created);
				exit;
			break;
		}
	}

	function backup_upload ($then= 'restore')
	{
		//tools & info
		global $pressbackup;
		$preferences= get_option('pressbackup_preferences');
		$pressbackup->import('backup_functions.php');

		//return if exists upload errors
		if(!$this->pressbackup_check_backup_upload() || !$this->pressbackup_check_backup_integrity($_FILES['backup']['tmp_name']))
		{
			$pressbackup->redirect(array('controller'=>'principal', 'function'=>'backup_upload_page'));
		}

		//create backup file
		$pb = new pressbackup_backup();
		$pb->restore(array('tmp_name'=>$_FILES['backup']['tmp_name']));
		$pressbackup->redirect(array('controller'=>'principal', 'function'=>'dashboard'));
	}

	function backup_restore ($name= null)
	{
		//tools & info
		global $pressbackup;
		$preferences= get_option('pressbackup_preferences');
		$pressbackup->import('backup_functions.php');

		//check for folder permissions
		$permissions_problem = array();
		$dir = WP_CONTENT_DIR . DS;
		if( substr(sprintf('%o', @fileperms( $dir . 'themes')), -3) < '777'){ $permissions_problem[] ='themes'; }
		if( file_exists($dir . 'uploads') && substr(sprintf('%o', @fileperms( $dir . 'uploads')), -3) < '777'){ $permissions_problem[] ='uploads'; }
		if( substr(sprintf('%o', @fileperms( $dir . 'plugins')), -3) < '777'){ $permissions_problem[] ='plugins'; }

		if($permissions_problem) {
			$msg = "Warning: permissions denied to write on <b>".join('</b>, <b>', $permissions_problem)."</b> folder/s, change the permissions if you want to be able to restore a backup";
			$pressbackup->Session->write( 'error_msg_perm', $msg);
			$pressbackup->redirect(array('controller'=>'principal', 'function'=>'dashboard'));
		}

		$pb = new pressbackup_backup();
		if(!$tmp_name=$pb->get($name))
		{
			$pressbackup->redirect(array('controller'=>'principal', 'function'=>'dashboard'));
		}
		elseif(!$this->pressbackup_check_backup_integrity($tmp_name))
		{
			$pressbackup->redirect(array('controller'=>'principal', 'function'=>'dashboard'));
		}

		$pb->restore(array('tmp_name'=>$tmp_name));
		$pressbackup->redirect(array('controller'=>'principal', 'function'=>'dashboard'));
	}

	function backup_get ($name=null)
	{
		//tools & info
		global $pressbackup;
		$preferences= get_option('pressbackup_preferences');
		$pressbackup->import('backup_functions.php');

		$pb = new pressbackup_backup();
		if(!$tmp_name=$pb->get($name))
		{
			$pressbackup->redirect(array('controller'=>'principal', 'function'=>'dashboard'));
		}
		elseif(!$this->pressbackup_check_backup_integrity($tmp_name))
		{
			$pressbackup->redirect(array('controller'=>'principal', 'function'=>'dashboard'));
		}

		ob_end_clean();
		$pressbackup->import('download.php');
		$pressbackup->View->set('file', $tmp_name);
	}

	function backup_get2 ($name=null)
	{
		//tools & info
		global $pressbackup;
		$preferences= get_option('pressbackup_preferences');
		$pressbackup->import('backup_functions.php');

		$pb = new pressbackup_backup();
		if(!$tmp_name=$pb->get2($name))
		{
			$pressbackup->redirect(array('controller'=>'principal', 'function'=>'dashboard'));
		}

		$pressbackup->redirect('http://pressbackup.com/pro/api/download/'.base64_encode($name));
	}

	function backup_delete ($name=null)
	{
		//tools & info
		global $pressbackup;
		$preferences= get_option('pressbackup_preferences');
		$pressbackup->import('backup_functions.php');

		$pb = new pressbackup_backup();
		$pb->delete($name);
		$pressbackup->redirect(array('controller'=>'principal', 'function'=>'dashboard'));
	}

//------------------------------
//	functions helpers
//------------------------------


	function pressbackup_check_backup_upload()
	{
		//tools
		global $pressbackup;
		$pressbackup->import('misc.php');

		if (!isset($_FILES['backup']) || $_FILES['backup']['error']==4)
		{
			$pressbackup->Session->write( 'error_msg', 'You sent an empty file or it is bigger than '.pressbackup_get_size_in('m', pressbackup_upload_max_filesize()).' Mb. Please try it again');
			return false;
		}
		if ($_FILES['backup']['error']!=0)
		{
			$pressbackup->Session->write( 'error_msg', 'There was a problem, maybe the file is bigger than '.pressbackup_get_size_in('m', pressbackup_upload_max_filesize()).' Mb. Please try it again');
			return false;
		}
		if ($_FILES['backup']['type']!='application/zip')
		{
			$pressbackup->Session->write( 'error_msg', 'Wrong file type');
			return false;
		}
		if (!is_uploaded_file($_FILES['backup']['tmp_name']))
		{
			$pressbackup->Session->write( 'error_msg', 'The file could not be uploaded correctly');
			return false;
		}
		return true;
	}

	function pressbackup_check_backup_integrity($zip_file)
	{
		//tools
		global $pressbackup;

		if(!file_exists($zip_file)){
			$pressbackup->Session->write( 'error_msg', 'file not found');
			return false;
		}

		$zip = new ZipArchive();
		if ($zip->open($zip_file) !== TRUE)
		{
			$pressbackup->Session->write( 'error_msg', 'Sorry, but the file is corrupt');
			return false;
		}
		$zip->close();
		return true;
	}

	function pressbackup_check_send_status()
	{
		//tools
		global $pressbackup;

		//ob_end_clean();
		if($pressbackup->Session->check( 'sent.log') || file_exists($pressbackup->Path->Dir['PBKTMP']. DS. 'sent.log')) {
			@unlink($pressbackup->Path->Dir['PBKTMP']. DS. 'sent.log');
			$pressbackup->Session->delete( 'sent.log');
			$pressbackup->Session->delete( 'sent.percent');
			exit('reload');
		}
		elseif ($pressbackup->Session->check( 'sent.percent')){
			exit('wait|'.$pressbackup->Session->read( 'sent.percent'));
		}
		exit('wait');
	}

}
?>
